==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkTriangularTexture.java <==
// java wrapper for vtkTriangularTexture object
//

package vtk;
import vtk.*;

public class vtkTriangularTexture extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetScaleFactor_2(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_2(id0); }

  private native double GetScaleFactor_3();
  public double GetScaleFactor()
    { return GetScaleFactor_3(); }

  private native void SetXSize_4(int id0);
  public void SetXSize(int id0)
    { SetXSize_4(id0); }

  private native int GetXSize_5();
  public int GetXSize()
    { return GetXSize_5(); }

  private native void SetYSize_6(int id0);
  public void SetYSize(int id0)
    { SetYSize_6(id0); }

  private native int GetYSize_7();
  public int GetYSize()
    { return GetYSize_7(); }

  private native void SetTexturePattern_8(int id0);
  public void SetTexturePattern(int id0)
    { SetTexturePattern_8(id0); }

  private native int GetTexturePatternMinValue_9();
  public int GetTexturePatternMinValue()
    { return GetTexturePatternMinValue_9(); }

  private native int GetTexturePatternMaxValue_10();
  public int GetTexturePatternMaxValue()
    { return GetTexturePatternMaxValue_10(); }

  private native int GetTexturePattern_11();
  public int GetTexturePattern()
    { return GetTexturePattern_11(); }

  public vtkTriangularTexture() { super(); }

  public vtkTriangularTexture(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkTriangularTexture.java <==
// java wrapper for vtkTriangularTexture object
//

package vtk;
import vtk.*;

public class vtkTriangularTexture extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetScaleFactor_2(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_2(id0); }

  private native double GetScaleFactor_3();
  public double GetScaleFactor()
    { return GetScaleFactor_3(); }

  private native void SetXSize_4(int id0);
  public void SetXSize(int id0)
    { SetXSize_4(id0); }

  private native int GetXSize_5();
  public int GetXSize()
    { return GetXSize_5(); }

  private native void SetYSize_6(int id0);
  public void SetYSize(int id0)
    { SetYSize_6(id0); }

  private native int GetYSize_7();
  public int GetYSize()
    { return GetYSize_7(); }

  private native void SetTexturePattern_8(int id0);
  public void SetTexturePattern(int id0)
    { SetTexturePattern_8(id0); }

  private native int GetTexturePatternMinValue_9();
  public int GetTexturePatternMinValue()
    { return GetTexturePatternMinValue_9(); }

  private native int GetTexturePatternMaxValue_10();
  public int GetTexturePatternMaxValue()
    { return GetTexturePatternMaxValue_10(); }

  private native int GetTexturePattern_11();
  public int GetTexturePattern()
    { return GetTexturePattern_11(); }

  public vtkTriangularTexture() { super(); }

  public vtkTriangularTexture(long id) { super(id); }
  public native long   VTKInit();

}
